checkScalarNA(x, null.ok = FALSE)
check_scalar_na(x, null.ok = FALSE)
assertScalarNA(x, null.ok = FALSE, .var.name = vname(x), add = NULL)
assert_scalar_na(x, null.ok = FALSE, .var.name = vname(x), add = NULL)
testScalarNA(x, null.ok = FALSE)
test_scalar_na(x, null.ok = FALSE)
expect_scalar_na(x, null.ok = FALSE, info = NULL, label = vname(x))logical(1)]
If set to TRUE, x may also be NULL.
In this case only a type check of x is performed, all additional checks are disabled.character(1)]
Name of the checked object to print in assertions. Defaults to
the heuristic implemented in vname.AssertCollection]
Collection to store assertion messages. See AssertCollection.expect_that.character(1)]
Name of the checked object to print in messages. Defaults to
the heuristic implemented in vname.TRUE. If the check
is not successful, assertScalarNA/assert_scalar_na
throws an error message, testScalarNA/test_scalar_na
returns FALSE,
and checkScalarNA returns a string with the error message.
The function expect_scalar_na always returns an
expectation.
checkCount,
checkFlag, checkInt,
checkScalar, checkString
testScalarNA(1)
testScalarNA(NA_real_)
testScalarNA(rep(NA, 2))
Run the code above in your browser using DataLab